@@ -25,7 +25,7 @@ import commands
 import cPickle
 from subprocess import *
 from pge_buffer import SyntaxLoader,CodeBuffer
-#import gtksourceview2
+import pge_preferences 
 
 ###############################################################################
 # @brief Code editor widget
@@ -35,7 +35,7 @@ class Editor (hildon.TextView):
   #############################################################################
   # @brief Initialize CodeEditor
   #############################################################################
-  def __init__ (self,language=None):
+  def __init__ (self,language=None,font_name='Monospace',font_size='11'):
 
 #    self.language_manager=gtksourceview2.LanguageManager()
     if language != None:
@@ -45,11 +45,15 @@ class Editor (hildon.TextView):
     self.buffer=CodeBuffer(lang=lang)
     hildon.TextView.__init__ (self)
     self.set_buffer(self.buffer)
+    
+    prefs = pge_preferences.Prefs()
+    prefs.load()
+    if prefs.prefs_dict['hildon_text_completion']==False:
+      self.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_FULL)
 
     self.set_editable (True)
     self.no_edit_mode = True
-    self.font_size=11
-    self.modify_font (pango.FontDescription ("Monospace "+str(self.font_size)))
+    self.modify_font (pango.FontDescription (font_name+" "+str(font_size)))
     self.language = language
     self.searched_text = None
 
@@ -179,7 +183,11 @@ class Editor (hildon.TextView):
       buffer.place_cursor(iter)
       self.scroll_to_iter(iter,0)
     except IndexError:
-      print "End text reached"
+      note = osso.SystemNote(self.get_parent().get_parent()._parent.context)
+      result = note.system_note_infoprint("End text reached")
+      self.searched_text_count = 0
+      
+
 
   #############################################################################
   # @brief Find a substring
