@@ -93,6 +93,21 @@ Hilighted "Languages":
 Roadmap :
 
 • Version 3.0.1 :
+◦ Fix Bug #6397
+◦ Fix Bug #6399
+◦ Implement simple cacher in parser
+◦ Fix icon in open dialog
+
+• Version 3.0.2 :
+◦ Prefs : default language
+◦ Prefs : Auto rotate option
+◦ Prefs : font and text size
+◦ Prefs : enable or not word completion
+◦ Fix Bug #6522
+◦ Fix Bug #6547
+◦ Fix Bug #7021
+
+• Version 3.0.3 :
 ◦ Prefs : indent size
 ◦ Prefs : font and text size
 ◦ Welcome screen
