@@ -22,18 +22,65 @@ import os
 from subprocess import *
 import commands
 import gobject
+import pge_preferences
+
+LANGUAGES = (('.R','R'),
+            ('.ada','ada'),
+            ('.c','c'),
+            ('.changelog','changelog'),
+            ('.cpp','cpp'),
+            ('.csharp','csharp'),
+            ('.desktop','desktop'),
+            ('.css','css'),
+            ('.diff','diff'),
+            ('.fort','fortran'),
+            ('.gtkrc','gtkrc'),
+            ('.haskell','haskell'),
+            ('.html','html'),
+            ('.idl','idl'),
+            ('.ini','ini'),
+            ('.java','java'),
+            ('.js','javascript'),
+            ('.tex','latex'),
+            ('.lua','lua'),
+            ('makefile','makefile'),
+            ('markdown','markdown'),
+            ('.msil','msil'),
+            ('nemerle','nemerle'),
+            ('octave','octave'),
+            ('.pas','pascal'),
+            ('.pl','perl'),
+            ('.php','php'),
+            ('.po','po'),
+            ('.py','python'),
+            ('.rb','ruby'),
+            ('.scheme','scheme'),
+            ('.sh','sh'),
+            ('.tcl','tcl'),
+            ('texinfo','texinfo'),
+            ('.vb','vbnet'),
+            ('verilog','verilog'),
+            ('vhdl','vhdl'),
+            ('.xml','xml'),
+            )
 
 class Window(hildon.Window):
   def __init__(self,filepath=None,caller=None):
     hildon.Window.__init__ (self)
-    FremantleRotation('net.khertan.pygtkeditor',self)
+    self.prefs = pge_preferences.Prefs()
+    self.prefs.load()
 
+    if self.prefs.prefs_dict['auto_rotate']==True:
+      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
+    else:
+      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
+    
     self.is_fullscreen = False
     
     self._parent = caller
     self.filepath=filepath
 
-    self.code_editor=pge_editor.Editor(self._detect_language(self.filepath))
+    self.code_editor=pge_editor.Editor(self._detect_language(self.filepath),font_name=self.prefs.prefs_dict['font_name'],font_size=self.prefs.prefs_dict['font_size'])
 
     self.toolbar = self.create_toolbar()
     self.add_toolbar(self.toolbar)
@@ -87,6 +134,16 @@ class Window(hildon.Window):
       except:
         pass
 
+  def apply_prefs(self):
+    self.prefs.load()
+    #rotate
+    if self.prefs.prefs_dict['auto_rotate']==True:
+      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.AUTOMATIC)
+    else:
+      FremantleRotation('net.khertan.pygtkeditor',self,mode=FremantleRotation.NEVER)
+    #font / size
+    self.code_editor.modify_font(pango.FontDescription (self.prefs.prefs_dict['font_name']+" "+str(self.prefs.prefs_dict['font_size'])))
+    
   def onHideFind(self, widget):
     self.findToolBar.hide()
     self.searched_text = None
@@ -121,51 +178,14 @@ class Window(hildon.Window):
     return 'python'
     
   def _detect_language(self,filepath):
+    
     if filepath==None:
-      return None
-    langs = (('.R','R'),
-            ('.ada','ada'),
-            ('.c','c'),
-            ('.changelog','changelog'),
-            ('.cpp','cpp'),
-            ('.csharp','csharp'),
-            ('.desktop','desktop'),
-            ('.css','css'),
-            ('.diff','diff'),
-            ('.fort','fortran'),
-            ('.gtkrc','gtkrc'),
-            ('.haskell','haskell'),
-            ('.html','html'),
-            ('.idl','idl'),
-            ('.ini','ini'),
-            ('.java','java'),
-            ('.js','javascript'),
-            ('.tex','latex'),
-            ('.lua','lua'),
-            ('makefile','makefile'),
-            ('markdown','markdown'),
-            ('.msil','msil'),
-            ('nemerle','nemerle'),
-            ('octave','octave'),
-            ('.pas','pascal'),
-            ('.pl','perl'),
-            ('.php','php'),
-            ('.po','po'),
-            ('.py','python'),
-            ('.rb','ruby'),
-            ('.scheme','scheme'),
-            ('.sh','sh'),
-            ('.tcl','tcl'),
-            ('texinfo','texinfo'),
-            ('.vb','vbnet'),
-            ('verilog','verilog'),
-            ('vhdl','vhdl'),
-            ('.xml','xml'),
-            )
+      return self.prefs.prefs_dict['default_language']
             
-    for extension,lang in langs:
+    for extension,lang in LANGUAGES:
       if filepath.endswith(extension.lower()):
         return lang
+    return self.prefs.prefs_dict['default_language']
 
   def on_key_press(self, widget, event, *args):
     if (event.state==gtk.gdk.CONTROL_MASK):
@@ -207,19 +227,23 @@ class Window(hildon.Window):
     pge_help.Help()
 
   def save_file(self,filepath):
-    f = open(filepath,'w')
-    buf = self.code_editor.get_buffer()
-    start,end = buf.get_bounds()
-    f.write(buf.get_text(start,end))
-    f.close()
-    self.set_title(os.path.basename(filepath))
-    self.saved=True
-    self.filepath = filepath
-    note = osso.SystemNote(self._parent.context)
-    result = note.system_note_infoprint(self.filepath+' Saved')
-    language = self._detect_language(self.filepath)
-    if self.code_editor.language != language:
-      self.code_editor.reset_language(language)
+    try:
+      f = open(filepath,'w')
+      buf = self.code_editor.get_buffer()
+      start,end = buf.get_bounds()
+      f.write(buf.get_text(start,end))
+      f.close()
+      self.set_title(os.path.basename(filepath))
+      self.saved=True
+      self.filepath = filepath
+      note = osso.SystemNote(self._parent.context)
+      result = note.system_note_infoprint(self.filepath+' Saved')
+      language = self._detect_language(self.filepath)
+      if self.code_editor.language != language:
+        self.code_editor.reset_language(language)
+    except StandardError,e:
+      note = osso.SystemNote(self._parent.context)
+      result = note.system_note_dialog('An error occurs saving file :\n'+str(e))
 
   def open_dialog(self):
       #fsm = hildon.FileSystemModel()
@@ -261,23 +285,23 @@ class Window(hildon.Window):
       fc.destroy()
 
   def open_file(self,filepath):
-    f = open(filepath,'r')
-    self.filepath = os.path.abspath(filepath)
-    buf = self.code_editor.get_buffer()
-    buf.begin_user_action()
-    text = f.read()
-#    text = text.replace('\n','\n\r')
-    f.close()
-    buf.begin_not_undoable_action()
-    buf.set_text(text)
-    buf.end_not_undoable_action()
-    buf.end_user_action()
-    manager = gtk.recent_manager_get_default()
-    manager.add_item('file://'+filepath)
-
-#    self.code_editor.reset_language()
-#    f.close()
-
+    try:
+      f = open(filepath,'r')
+      self.filepath = os.path.abspath(filepath)
+      buf = self.code_editor.get_buffer()
+      buf.begin_user_action()
+      text = f.read()
+      f.close()
+      buf.begin_not_undoable_action()
+      buf.set_text(text)
+      buf.end_not_undoable_action()
+      buf.end_user_action()
+      manager = gtk.recent_manager_get_default()
+      manager.add_item('file://'+filepath)
+    except StandardError,e:
+      note = osso.SystemNote(self._parent.context)
+      result = note.system_note_dialog('An error occurs opening file :\n'+str(e))
+  
   def create_toolbar(self):
     toolbar = gtk.Toolbar()
 #    label = 'Edit'
@@ -393,6 +417,10 @@ class Window(hildon.Window):
       self.save_as()
     elif label == 'Help':
       self.show_help()
+    elif label == 'Settings':
+      prefs = pge_preferences.Prefs()
+      prefs.load()
+      prefs.edit(self)
     else:
       print "Menu Button clicked: %s" % label
 
@@ -428,7 +456,7 @@ class Window(hildon.Window):
     label = 'Settings'
     self.settings_menu_button.set_label(label)
     self.settings_menu_button.connect("clicked", self.menu_button_clicked, label)
-#    menu.append(self.settings_menu_button)
+    menu.append(self.settings_menu_button)
     self.help_menu_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO) 
     label = 'Help'                                             
     self.help_menu_button.set_label(label)                   
